/**********************************************/
/*  M. Escobar, E. Fernández, F. Bernardi     */
/*  Análisis de datos con Stata               */
/*  Madrid. CIS. 2020                         */
/**********************************************/
/* Usa fichero5 paisesanchos panel5 panel5b   */
/**********************************************/
/*               Introducción                 */
/**********************************************/
version 14
log close _all
capture confirm file "Data\panel5.dta"
if _rc!=0{
/* Si el programa se detiene aquí es porque no se encuentran los datos. 
Estos han de situarse en el subdirectorio Data. Para solucionarlo, 
se recomienda que vuelva a descomprimir el fichero de ejercicios */
exit
}
log using "capitulo5", replace
clear
set mem 500M
set more off
set scheme sj
/**********************************************/
/*                                            */
/* Ejercicios del capítulo 5                  */
/*                                            */
/**********************************************/

/**********************************************/
/*           Manipulación de datos            */
/**********************************************/
use "Data\fichero5.dta", clear
sort edad
list sexo edad, clean
sort sexo edad
list sexo edad, clean
gsort -edad
gsort edad, generate (orden_edad)
list sexo edad orden_edad, clean

/**********************************************/
/*           Selección de casos               */
/**********************************************/
use "Data\fichero5.dta", clear
summarize edad in 1/5
list sexo edad  in -5/l, clean
summarize edad if sexo == 2 & edad<=20
tabulate sexo if region ==1 | region== 2 & edad >20
tabulate sexo if (region ==1 | region == 2) & edad>20

/**********************************************/
/*           Agrupación de casos              */
/**********************************************/
use "Data\fichero5.dta", clear
sort sexo
by sexo: summarize edad
sort sexo region
by sexo region: summarize edad
bysort sexo region: summarize edad

/**********************************************/
/*        Ficheros anchos y alargados         */
/**********************************************/
use "Data\paisesanchos.dta", clear
list, clean
reshape long estudiantes, i(pais) j(año)
list, clean
reshape wide estudiantes, i(pais) j(año)


/**********************************************/
/*           Generación y modificación        */
/**********************************************/
use "Data\panel5.dta", clear
generate total = 1
generate edad=2000-añonacimiento
replace edad=2000-añonacimiento-1 if mesnacimiento>2
list mesnacimiento añonacimiento edad in 1/5, clean
generate edadc=edad^2
generate lnedad=ln(edad)
list edad edadc lnedad in -3/l, clean
set seed 43214
generate naleat = int(runiform()*100)+1
generate aleatoriobinomial = rbinomial(4,.5)
generate aleatorionormal=rnormal(5,2)
list naleat aleatoriobinomial aleatorionormal in 1/3, clean
list sexo edad in 1/3
generate orden = _n
sort edad
list sexo edad in 1/3
sort orden
list sexo edad in 1/3

/**********************************************/
/*       Transformaciones de equivalencia     */
/**********************************************/
use "Data\panel5b.dta", clear
recode sexo (3/.=.)
recode p201 p203 p204 (1=4)(2=3)(3=2)(4=1)
recode edad (min/35=1)(36/50=2) (51/65=3) (66/max=4) (else=.), into(edadr)
recode edad (min/35=1 "Hasta 35") (36/50=2 "36-50") (51/65=3 "51-65") (66/max=4 "Mas de 65") (else=.), into(edadr2)
tabulate edadr2

/**********************************************/
/*       Transformaciones lógicas             */
/**********************************************/
use "Data\panel5b.dta", clear
generate joven=1 if edad<=30
replace joven=0 if edad>30 & edad<.
generate joven2=(edad<=30) if edad<.
generate sexedad=1 if sexo==1 & edad<=30
replace sexedad=2 if sexo==2 & edad<=30
replace sexedad=3 if sexo==1 & edad>30 & edad<.
replace sexedad=4 if sexo==2 & edad >30 & edad<.
label define sexedad 1 "Joven hombre" 2 "Joven mujer" ///
                     3 "Hombre mayor" 4 "Mujer mayor"
label value sexedad sexedad
tabulate sexedad
generate sexedad2=sexo+2 if edad<.
replace sexedad2=sexo if edad<=30
recode sexo 1=3 2=4, into(sexedad3)
recode sexedad3 3=1  4=2 if edad<=30
generate sexedad4=cond(edad<=30,sexo,sexo+2) if edad<.

/**********************************************/
/*       Transformaciones extendidas          */
/**********************************************/
use "Data\panel5b.dta", clear
recode edad (min/35=1 "Hasta 35") (36/50=2 "36-50") (51/65=3 "51-65") (66/max=4 "Mas de 65") (else=.), into(edadr)
egen acuerdos=anycount(p201-p204), values (1,2)
egen edadS=std(edad)
summarize edadS


/**********************************************/
/*         Instrucciones especiales           */
/**********************************************/
summarize acuerdos
return list
display "La media es " r(mean) " y la desviación típica " r(sd)
display "Rango= " %1.0f r(max)-r(min) "; C. de variación= " %3.1f r(sd)/r(mean)
global media_acuerdos=r(mean)
generate acuerdos0=acuerdos-$media_acuerdos
summarize acuerdos0
return list
display "Nueva media: " %3.1f r(mean), "Media anterior: " %3.1f $Media_acuerdos
global vv="p201-p204"
global condi1="if sexo==1 & edad>35 & edad<=50"
list sexo edad $vv $condi1 in 1/40, clean
foreach X of varlist total-acuerdos {
  egen `X'_e=std(`X')
}
// equivalencia: egen total_e=std(total)
// equivalencia: egen promedio_e=std(promedio)
// equivalencia: egen acuerdos_e=std(acuerdos)

foreach X of numlist 1/2 {
  generate sexo`X'=(sexo==`X') if sexo<.
}
foreach i of numlist 1/2 {
   local x: word `i' of hombre mujer
   generate `x'=(sexo==`i') if sexo<.
   }
foreach j of numlist 1/4 {
  local y: word `j' of joven adulto maduro mayor
  generate `y'=(edadr==`j') if edadr<.
  }
list sexo hombre mujer edad edadr joven-mayor in 2/6, clean noobs

log close
set more on
